@@ -1,5 +1,6 @@
 import os
 import sys
+import stat
 import shutil
 import backstage
 import subprocess
@@ -112,6 +113,8 @@ class Project():
         """build the virtual environment for this backstage project"""
         venvdir = os.path.join(self.PROJECT_ROOT,'venv')
         cmd = '%s/build_virtualenv' % (venvdir)
+        st = os.stat(cmd)
+        os.chmod(cmd, st.st_mode | stat.S_IEXEC)
         subprocess.call(cmd)
         execfile(os.path.join(venvdir,'bin/activate_this.py'))
         return
